==> wow_views-0.0.6.tar.gz: lib/compoment/view/ThongTin1.dart <==
import 'package:flutter/material.dart';
import 'package:wowit/imageUrl.dart';
import 'package:wowit/methods.dart';


class ThongTin1 {

  Widget getMainView(Map<String, dynamic> data) {
    var dataReponse = Methods.getList(data['data'], 'sp_dsSuKien');
    if(dataReponse.length>0){
      Map<String,Object> itemSuKien = dataReponse[0];
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
        Text(Methods.getString(itemSuKien, 'title'),maxLines: 3,
          style: const TextStyle(
          color: Colors.black,
          fontWeight: FontWeight.bold,
          fontSize: 18,),),
         const SizedBox(height: 8,),
        _iconTitle(
            icon: ImageByID.getUrlImage(2206),
            title: _textTime(itemSuKien)
        ),
        const SizedBox(height: 8,),
        _iconTitle(
            icon: ImageByID.getUrlImage(1048),
            title: Methods.getString(itemSuKien, 'diaDiemToChuc')
        ),
        const SizedBox(height: 8,),
        _iconTitle(
            icon: ImageByID.getUrlImage(2206),
            title: Methods.getString(itemSuKien, 'titleHinhThuc')
        ),
      ],);
    }else{
      return const SizedBox.shrink();
    }
  }
  
  Widget _iconTitle({@required String icon,@required String title}){
    return Row(children: [
      Image.network(Methods.getURL(icon),height: 20, width: 20,),
      const SizedBox(width: 8,),
      Expanded(child: Text(title??'',maxLines: 2))
    ],);
  }
  String _textTime(Map<String, Object> data){
    String textTime = '';
    DateTime dateTimeStart = Methods.getDateTime(data, 'tgDienRaTu');
    DateTime dateTimeEnd = Methods.getDateTime(data, 'tgDienRaDen');
    if(Methods.showDate(dateTimeEnd) == Methods.showDate(dateTimeStart)){
      textTime = '${_showTime(dateTimeStart)} - ${_showTime(dateTimeEnd)} : ${Methods.showDate(dateTimeStart)}';
    }else{
      textTime = '${_showDateTime(dateTimeStart)} - ${_showDateTime(dateTimeEnd)}';
    }
    return textTime;
  }
  String _showTime(DateTime date){
    return '${date.hour}:${date.minute}';
  }
  String _showDateTime(DateTime date){
    return '${Methods.showDate(date)} ${date.hour}:${date.minute}';
  }
}

==> wow_views-0.0.7.tar.gz: lib/compoment/view/ThongTin1.dart <==
import 'package:flutter/material.dart';
import 'package:wowit/imageUrl.dart';
import 'package:wowit/methods.dart';


class ThongTin1 {

  Widget getMainView(Map<String, dynamic> data,String tableName) {
    var dataReponse = Methods.getList(data['data'], tableName);
    if(dataReponse.isNotEmpty){
      Map<String,Object> itemSuKien = dataReponse[0];
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
        Text(Methods.getString(itemSuKien, 'title'),maxLines: 3,
          style: const TextStyle(
          color: Colors.black,
          fontWeight: FontWeight.bold,
          fontSize: 18,),),
         const SizedBox(height: 8,),
        _iconTitle(
            icon: ImageByID.getUrlImage(2206),
            title: _textTime(itemSuKien)
        ),
        const SizedBox(height: 8,),
        _iconTitle(
            icon: ImageByID.getUrlImage(1048),
            title: Methods.getString(itemSuKien, 'diaDiemToChuc')
        ),
        const SizedBox(height: 8,),
        _iconTitle(
            icon: ImageByID.getUrlImage(2206),
            title: Methods.getString(itemSuKien, 'titleHinhThuc')
        ),
      ],);
    }else{
      return const SizedBox.shrink();
    }
  }
  
  Widget _iconTitle({@required String icon,@required String title}){
    return Row(children: [
      Image.network(Methods.getURL(icon),height: 20, width: 20,),
      const SizedBox(width: 8,),
      Expanded(child: Text(title??'',maxLines: 2))
    ],);
  }
  String _textTime(Map<String, Object> data){
    String textTime = '';
    DateTime dateTimeStart = Methods.getDateTime(data, 'tgDienRaTu');
    DateTime dateTimeEnd = Methods.getDateTime(data, 'tgDienRaDen');
    if(Methods.showDate(dateTimeEnd) == Methods.showDate(dateTimeStart)){
      textTime = '${_showTime(dateTimeStart)} - ${_showTime(dateTimeEnd)} : ${Methods.showDate(dateTimeStart)}';
    }else{
      textTime = '${_showDateTime(dateTimeStart)} - ${_showDateTime(dateTimeEnd)}';
    }
    return textTime;
  }
  String _showTime(DateTime date){
    return '${date.hour}:${date.minute}';
  }
  String _showDateTime(DateTime date){
    return '${Methods.showDate(date)} ${date.hour}:${date.minute}';
  }
}
